@@ -43,6 +43,7 @@ module TZInfo
         c.timezone 'Antarctica/Vostok', -392, 5, 1069, 10, 'Vostok Station, S Magnetic Pole'
         c.timezone 'Antarctica/DumontDUrville', -200, 3, 8401, 60, 'Dumont-d\'Urville Station, Terre Adelie'
         c.timezone 'Antarctica/Syowa', -124211, 1800, 3959, 100, 'Syowa Station, E Ongul I'
+        c.timezone 'Antarctica/Macquarie', -109, 2, 3179, 20, 'Macquarie Island Station, Macquarie Island'
       end
       country 'AR', 'Argentina' do |c|
         c.timezone 'America/Argentina/Buenos_Aires', -173, 5, -1169, 20, 'Buenos Aires (BA, CF)'
@@ -568,11 +569,14 @@ module TZInfo
         c.timezone 'America/Mexico_City', 97, 5, -1983, 20, 'Central Time - most locations'
         c.timezone 'America/Cancun', 253, 12, -2603, 30, 'Central Time - Quintana Roo'
         c.timezone 'America/Merida', 629, 30, -5377, 60, 'Central Time - Campeche, Yucatan'
-        c.timezone 'America/Monterrey', 77, 3, -6019, 60, 'Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas'
+        c.timezone 'America/Monterrey', 77, 3, -6019, 60, 'Mexican Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas away from US border'
+        c.timezone 'America/Matamoros', 155, 6, -195, 2, 'US Central Time - Coahuila, Durango, Nuevo Leon, Tamaulipas near US border'
         c.timezone 'America/Mazatlan', 1393, 60, -1277, 12, 'Mountain Time - S Baja, Nayarit, Sinaloa'
-        c.timezone 'America/Chihuahua', 859, 30, -1273, 12, 'Mountain Time - Chihuahua'
+        c.timezone 'America/Chihuahua', 859, 30, -1273, 12, 'Mexican Mountain Time - Chihuahua away from US border'
+        c.timezone 'America/Ojinaga', 887, 30, -1253, 12, 'US Mountain Time - Chihuahua near US border'
         c.timezone 'America/Hermosillo', 436, 15, -3329, 30, 'Mountain Standard Time - Sonora'
-        c.timezone 'America/Tijuana', 488, 15, -7021, 60, 'Pacific Time'
+        c.timezone 'America/Tijuana', 488, 15, -7021, 60, 'US Pacific Time - Baja California near US border'
+        c.timezone 'America/Santa_Isabel', 303, 10, -1723, 15, 'Mexican Pacific Time - Baja California away from US border'
       end
       country 'MY', 'Malaysia' do |c|
         c.timezone 'Asia/Kuala_Lumpur', 19, 6, 1017, 10, 'peninsular Malaysia'
@@ -683,7 +687,7 @@ module TZInfo
         c.timezone 'Europe/Kaliningrad', 3283, 60, 41, 2, 'Moscow-01 - Kaliningrad'
         c.timezone 'Europe/Moscow', 223, 4, 451, 12, 'Moscow+00 - west Russia'
         c.timezone 'Europe/Volgograd', 731, 15, 533, 12, 'Moscow+00 - Caspian Sea'
-        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow+01 - Samara, Udmurtia'
+        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow - Samara, Udmurtia'
         c.timezone 'Asia/Yekaterinburg', 1137, 20, 303, 5, 'Moscow+02 - Urals'
         c.timezone 'Asia/Omsk', 55, 1, 367, 5, 'Moscow+03 - west Siberia'
         c.timezone 'Asia/Novosibirsk', 1651, 30, 995, 12, 'Moscow+03 - Novosibirsk'
@@ -694,8 +698,8 @@ module TZInfo
         c.timezone 'Asia/Vladivostok', 259, 6, 1979, 15, 'Moscow+07 - Amur River'
         c.timezone 'Asia/Sakhalin', 1409, 30, 1427, 10, 'Moscow+07 - Sakhalin Island'
         c.timezone 'Asia/Magadan', 1787, 30, 754, 5, 'Moscow+08 - Magadan'
-        c.timezone 'Asia/Kamchatka', 3181, 60, 3173, 20, 'Moscow+09 - Kamchatka'
-        c.timezone 'Asia/Anadyr', 259, 4, 10649, 60, 'Moscow+10 - Bering Sea'
+        c.timezone 'Asia/Kamchatka', 3181, 60, 3173, 20, 'Moscow+08 - Kamchatka'
+        c.timezone 'Asia/Anadyr', 259, 4, 10649, 60, 'Moscow+08 - Bering Sea'
       end
       country 'RW', 'Rwanda' do |c|
         c.timezone 'Africa/Kigali', -39, 20, 451, 15
