@@ -153,6 +153,7 @@ module TZInfo
       timezone 'America/Manaus'
       linked_timezone 'America/Marigot'
       timezone 'America/Martinique'
+      timezone 'America/Matamoros'
       timezone 'America/Mazatlan'
       linked_timezone 'America/Mendoza'
       timezone 'America/Menominee'
@@ -171,6 +172,7 @@ module TZInfo
       timezone 'America/Noronha'
       timezone 'America/North_Dakota/Center'
       timezone 'America/North_Dakota/New_Salem'
+      timezone 'America/Ojinaga'
       timezone 'America/Panama'
       timezone 'America/Pangnirtung'
       timezone 'America/Paramaribo'
@@ -187,6 +189,7 @@ module TZInfo
       timezone 'America/Resolute'
       timezone 'America/Rio_Branco'
       linked_timezone 'America/Rosario'
+      timezone 'America/Santa_Isabel'
       timezone 'America/Santarem'
       timezone 'America/Santiago'
       timezone 'America/Santo_Domingo'
@@ -215,6 +218,7 @@ module TZInfo
       timezone 'Antarctica/Casey'
       timezone 'Antarctica/Davis'
       timezone 'Antarctica/DumontDUrville'
+      timezone 'Antarctica/Macquarie'
       timezone 'Antarctica/Mawson'
       timezone 'Antarctica/McMurdo'
       timezone 'Antarctica/Palmer'
